==> fasstr_0.4.0.tar.gz: fasstr/R/zzz.R <==
.onLoad <-
  function(libname = find.package("fasstr"),
           pkgname = "fasstr") {
    # CRAN Note avoidance
    if (getRversion() >= "2.15.1")
      utils::globalVariables(
        # Vars used in Non-Standard Evaluations, declare here to avoid CRAN warnings
        ## This is getting ridiculous
        c("STATION_NUMBER",
          "DRAINAGE_AREA_GROSS",
          "Basin_Area_sqkm.y",
          "Basin_Area_sqkm.x",
          "AnalysisYear",
          "Cumul_Volume_m3",
          "Cumul_Volume_m3.y",
          "Cumul_Volume_m3.x",
          "Date",
          "Value",
          "Cumul_Yield_mm",
          "Cumul_Yield_mm.y",
          "Cumul_Yield_mm.x",
          "Month",
          "Stat",
          "Statistic",
          "daily_total",
          "Seasons2",
          "Seasons4",
          "Year",
          "RollingValue",
          "MIN_VALUE",
          "AnalysisDoY",
          "complete_yr",
          "LOWER",
          "UPPER",
          "Days_Below_Normal",
          "Days_Above_Normal",
          "Cumul_Flow",
          "MonthName",
          "LTMAD",
          "PEAK_CODE",
          "Measure",
          "value",
          "dPIII",
          "pPIII",
          "qPIII",
          "mPIII",
          "prob",
          "quantile",
          "distr",
          "Return",
          "DayofYear",
          "P5",
          "P25",
          "P75",
          "P95",
          "Minimum",
          "Maximum",
          "Mean",
          "AnalysisDate",
          "Median",
          "StandardDeviation",
          "Percentile",
          "Monthly_Total",
          "n_Q",
          "n_missing_Q",
          "Basin_Area_sqkm_temp",
          "Cumulative_total",
          "Cumul_Total",
          "Parameter",
          "StatMonth",
          "Units",
          "WaterYear",
          "WaterDayofYear",
          "Min_1_Day",
          "Min_3_Day",
          "Min_7_Day",
          "Min_30_Day",
          "AnalysisMonth",
          "Seasons_temp",
          "Season",
          "Basin_Area_sqkm2",
          "Basin_Area_sqkm",
          "CalendarYear",
          "STATION_NAME",
          "PROV_TERR_STATE_LOC",
          "HYD_STATUS",
          "LATITUDE",
          "LONGITUDE",
          "REGULATED",
          "RHBN",
          "REAL_TIME",
          "Info",
          "Month_Mean",
          "Annual_Mean",
          "miss_plots",
          "MAX_VALUE",
          "Return_P",
          "STATION_Upper")
      )
    invisible()
  }

==> fasstr_0.5.2.tar.gz: fasstr/R/zzz.R <==
.onLoad <-
  function(libname = find.package("fasstr"),
           pkgname = "fasstr") {
    # CRAN Note avoidance
    if (getRversion() >= "2.15.1")
      utils::globalVariables(
        # Vars used in Non-Standard Evaluations, declare here to avoid CRAN warnings
        ## This is getting ridiculous
        c("STATION_NUMBER",
          "DRAINAGE_AREA_GROSS",
          "Basin_Area_sqkm.y",
          "Basin_Area_sqkm.x",
          "AnalysisYear",
          "Cumul_Volume_m3",
          "Cumul_Volume_m3.y",
          "Cumul_Volume_m3.x",
          "Date",
          "Value",
          "Cumul_Yield_mm",
          "Cumul_Yield_mm.y",
          "Cumul_Yield_mm.x",
          "Month",
          "Stat",
          "Statistic",
          "daily_total",
          "Seasons2",
          "Seasons4",
          "Year",
          "RollingValue",
          "MIN_VALUE",
          "AnalysisDoY",
          "complete_yr",
          "LOWER",
          "UPPER",
          "Days_Below_Normal",
          "Days_Above_Normal",
          "Cumul_Flow",
          "MonthName",
          "LTMAD",
          "PEAK_CODE",
          "Measure",
          "value",
          "dPIII",
          "pPIII",
          "qPIII",
          "mPIII",
          "prob",
          "quantile",
          "distr",
          "Return",
          "DayofYear",
          "P5",
          "P25",
          "P75",
          "P95",
          "Minimum",
          "Maximum",
          "Mean",
          "AnalysisDate",
          "Median",
          "StandardDeviation",
          "Percentile",
          "Monthly_Total",
          "n_Q",
          "n_missing_Q",
          "Basin_Area_sqkm_temp",
          "Cumulative_total",
          "Cumul_Total",
          "Parameter",
          "StatMonth",
          "Units",
          "WaterYear",
          "WaterDayofYear",
          "Min_1_Day",
          "Min_3_Day",
          "Min_7_Day",
          "Min_30_Day",
          "AnalysisMonth",
          "Seasons_temp",
          "Season",
          "Basin_Area_sqkm2",
          "Basin_Area_sqkm",
          "CalendarYear",
          "STATION_NAME",
          "PROV_TERR_STATE_LOC",
          "HYD_STATUS",
          "LATITUDE",
          "LONGITUDE",
          "REGULATED",
          "RHBN",
          "REAL_TIME",
          "Info",
          "Month_Mean",
          "Annual_Mean",
          "miss_plots",
          "MAX_VALUE",
          "Return_P",
          "STATION_Upper",
          "Missing",
          "Days",
          "Symbol",
          "complete_years",
          "n",
          "n_days",
          "No_Symbol",
          "Count",
          "symb_in_data",
          "Missing_Symbol",
          "Percent",
          "Value2",
          "Normal",
          ".data",
          "Min_Doy",
          "Min_Start",
          "Min_End",
          "Max_Doy",
          "Max_Start",
          "Max_End",
          "RollingValue_max",
          "RollingValue_min",
          "RollingValue_High",
          "RollingValue_Low",
          "n_na",
          "data",
          "start_year",
          "end_year",
          "name",
          'LTMAD_Percent')
      )
    invisible()
  }
